@@ -77,11 +77,9 @@ KitaBBSView::KitaBBSView( QWidget *parent, const char *name )
              SLOT( slotContextMenuRequested( QListViewItem*, const QPoint&, int ) ) );
     connect( Kita::FavoriteBoards::getInstance(), SIGNAL( changed() ), SLOT( refreshFavoriteBoards() ) );
     connect( this, SIGNAL( openURLRequestExt(
-                               const KURL&, const KParts::URLArgs&, QString, int, int,
-                               const KURL&, const KURL&, const QString&, const QString& ) ),
+                               const KURL&, const KParts::URLArgs&, QString, int, const KURL& ) ),
              signalCollection, SIGNAL( openURLRequestExt(
-                                           const KURL& , const KParts::URLArgs&, QString, int, int,
-                                           const KURL&, const KURL&, const QString&, const QString& ) ) );
+                                           const KURL& , const KParts::URLArgs&, QString, int, const KURL& ) ) );
 }
 
 KitaBBSView::~KitaBBSView()
@@ -135,6 +133,10 @@ bool KitaBBSView::isBoardURL( const QString& url ) const
  */
 bool KitaBBSView::downloadBoardList()
 {
+    // moved urls.
+    QValueList<QString> oldURLs;
+    QValueList<QString> newURLs;
+    
     QString tmpFile;
     QString url = KitaConfig::boardListURL();
     if ( !
@@ -183,6 +185,8 @@ bool KitaBBSView::downloadBoardList()
             if ( ret == Kita::Board_enrollNew ) newBoards += boardName + "  ( " + category.category_name + " )  " + boardURL + "\n";
             if ( ret == Kita::Board_enrollMoved ) oldBoards += boardName + "  ( " + category.category_name + " )  " + oldURL + "  ->  " + boardURL + "\n";
             count++;
+            oldURLs += oldURL;
+            newURLs += boardURL;
         }
     }
 
@@ -233,6 +237,14 @@ bool KitaBBSView::downloadBoardList()
         return FALSE;
     }
 
+    // if moved URL exists. move files.
+    for( int i=0; i<oldURLs.count(); i++ ) {
+        QString oldURL = oldURLs[ i ];
+        QString newURL = newURLs[ i ];
+        
+        qDebug("move %s -> %s", oldURL.latin1(), newURL.latin1());
+        Kita::BoardManager::moveBoard( oldURL, newURL );
+    }
     /*------------------------------------------------*/
 
     /* save config */
@@ -336,6 +348,12 @@ void KitaBBSView::showBoardList()
             }
             QString boardURL = value[ 0 ];
             QString boardName = value[ 1 ];
+            if ( boardURL.contains( '/' ) != 4 || boardURL.right( 1 ) != "/" ) {
+                // OK: http://pc8.2ch.net/linux/
+                // NG: http://www.machi.to/
+                // NG: http://find.2ch.net/enq/board.php
+                continue;
+            }
             QString oldURL;
             Kita::BoardManager::enrollBoard( boardURL, boardName, oldURL );
             Kita::BoardManager::loadBBSHistory( boardURL );
