@@ -350,7 +350,6 @@ void KitaBoardView::updateListViewItem( QListViewItem* item, Kita::Thread* threa
     }
 }
 
-
 void KitaBoardView::slotContextMenuRequested( QListViewItem* item, const QPoint& point, int )
 {
     enum {
@@ -360,6 +359,7 @@ void KitaBoardView::slotContextMenuRequested( QListViewItem* item, const QPoint&
         Menu_CopyTitleAndURL,
         Menu_Favorites,
         Menu_DeleteLog,
+        Menu_OpenByBackground,
         Menu_Property
     };
 
@@ -386,6 +386,7 @@ void KitaBoardView::slotContextMenuRequested( QListViewItem* item, const QPoint&
         popup.insertSeparator();
         popup.insertItem( i18n( "Delete Log" ), Menu_DeleteLog );
     }
+    popup.insertItem( i18n( "Open by background" ), Menu_OpenByBackground );
 
     popup.insertSeparator();
     popup.insertItem( i18n( "Property" ), Menu_Property );
@@ -418,6 +419,9 @@ void KitaBoardView::slotContextMenuRequested( QListViewItem* item, const QPoint&
     case Menu_DeleteLog:
         deleteLog( threadURL );
         break;
+    case Menu_OpenByBackground:
+        emit openURLRequestExt( datURL, KParts::URLArgs(), "kita_open_2chthread", 2 );
+        break;
     case Menu_Property: {
             // FIXME: memory leak
             Kita::ThreadProperty* propertyWidget = new Kita::ThreadProperty( 0 );
@@ -533,7 +537,6 @@ void KitaBoardView::loadHeaderOnOff()
 {
     QString configPath = locateLocal( "appdata", "subjectview.conf" );
     KConfig config( configPath );
-    QHeader* header = subjectList->header();
 
     config.setGroup( "Column" );
     for ( int i = Col_Begin; i <= Col_End; i++ ) {
