@@ -37,7 +37,7 @@
 KitaImgTabWidget::KitaImgTabWidget( QWidget* parent, const char* name, WFlags fl )
         : KitaTabWidgetBase( parent, name, fl )
 {
-    setXMLFile( "kitaimgtabwidgetui.rc" );
+    setXMLFile( "imagetabwidgetui.rc" );
     setTabBar( new KitaImgTabBar( this ) );
     setupActions();
 
