@@ -36,13 +36,24 @@ namespace Kita
         /* to : KitaMainWindow */
         void bookmarked( const QString& datURL, bool on );
         void openURLRequest( const KURL& url, const KParts::URLArgs& args = KParts::URLArgs() );
+        /**
+         *
+         * @param url URL to open.
+         * @param args arguments of URL. @see KParts::URLArgs
+         * @param mimetype MIME Type to open.
+         *     "kita_open_2chboard" : open the board.
+         *     "kita_open_2chthread" : open the thread.
+         *     "text/html" : open url with web browser. 
+         *     QString::null : use KIO::NetAccess::mimetype to decide mime type of url.
+         * @param usr1
+         *     1: open with tab(board, thread), image viewer is not hidden.
+         *     2: open by background(thread).
+         * @param usrUrl1 dat's URL(image viewer only)
+         *
+         */
         void openURLRequestExt( const KURL& url, const KParts::URLArgs& args = KParts::URLArgs(),
                                 QString mimetype = QString::null,
-                                int usr1 = 0, int usr2 = 0,
-                                const KURL& usrUrl1 = KURL(),
-                                const KURL& usrUrl2 = KURL(),
-                                const QString& usrStr1 = QString::null,
-                                const QString& usrStr2 = QString::null );
+                                int usr1 = 0, const KURL& usrUrl1 = KURL() );
         void setMainURLLine( const KURL& url );
         void setMainCaption( const QString& captionStr );
         void setMainStatusbar( const QString& statusStr );
@@ -96,7 +107,7 @@ namespace Kita
         /* to : KitaBoardView, FavoriteListView */
         void updateSubjectTab( const KURL& url );
 
-        /* to: KitaSubjectDock */
+        /* to: KitaBoardDock */
         void switchToSubject();
 
         /*--------------------------------*/
