@@ -20,11 +20,19 @@
 class FavoriteThreadsTest : public CppUnit::TestFixture
 {
     CPPUNIT_TEST_SUITE( FavoriteThreadsTest );
+    CPPUNIT_TEST( testToXML );
+    CPPUNIT_TEST( testThreads );
+    CPPUNIT_TEST( testReplace );
     CPPUNIT_TEST_SUITE_END();
 
+    QString m_xml;
 public:
     void setUp();
     void tearDown();
+
+    void testToXML();
+    void testThreads();
+    void testReplace();
 };
 
 #endif
