@@ -181,11 +181,11 @@ void KitaHTMLPart::connectSignals()
 
     /* click */
     connect( this, SIGNAL( openURLRequestExt(
-                               const KURL&, const KParts::URLArgs&, QString, int, int,
-                               const KURL&, const KURL&, const QString&, const QString& ) ),
+                               const KURL&, const KParts::URLArgs&, QString, int,
+                               const KURL& ) ),
              signalCollection, SIGNAL( openURLRequestExt(
-                                           const KURL& , const KParts::URLArgs&, QString, int, int,
-                                           const KURL&, const KURL&, const QString&, const QString& ) ) );
+                                           const KURL& , const KParts::URLArgs&, QString, int,
+                                           const KURL& ) ) );
 
 
     /* goto anchor */
@@ -1405,7 +1405,7 @@ void KitaHTMLPart::clickAnchor( const KURL& urlin )
             QString tmpurl = m_datURL.prettyURL();
             if ( id != QString::null ) tmpurl += "#" + id;
 
-            emit openURLRequestExt( urlin, KParts::URLArgs(), QString::null, active, 0, tmpurl );
+            emit openURLRequestExt( urlin, KParts::URLArgs(), QString::null, active, tmpurl );
             return ;
         }
         /* image */
@@ -1432,6 +1432,14 @@ void KitaHTMLPart::clickAnchor( const KURL& urlin )
         return ;
     }
 
+    /*---------------------------*/
+    /* show popupmenu for #bepop */
+
+    if ( refstr.left( 5 ) == "bepop" ) {
+        showBePopupMenu( refstr );
+        return ;
+    }
+
     /*-------------------------*/
     /* start multi-popup mdde  */
     if ( m_pushrightbt && startMultiPopup() ) return ;
@@ -1722,6 +1730,57 @@ void KitaHTMLPart::showIDPopup( const QString& refstr )
 
 
 
+/*---------------------------------------------------------*/
+/* popup menu that is opened when user clicked be anchor.  */
+/* This funtcion is called in only clickAnchor().          */ /* private */
+void KitaHTMLPart::showBePopupMenu( const QString& refstr )
+{
+    QString strURL = "http://be.2ch.net/test/p.php?i=" + refstr.mid( 5 )
+                    + "&u=d:" + Kita::DatManager::threadURL( m_datURL ) + "/l50";
+
+    if ( m_pushrightbt ) {
+        /*---------------------*/
+        /* create popup menu */
+        KPopupMenu *popupMenu = new KPopupMenu( view() );
+        popupMenu->clear();
+
+        enum{
+            BEMENU_COPYURL,
+            BEMENU_SHOWBROWSER
+        };
+    
+        QClipboard * clipboard = QApplication::clipboard();
+    
+        popupMenu->insertItem( i18n( "copy URL" ), BEMENU_COPYURL );
+        popupMenu->insertItem( i18n( "Open with Web Browser" ), BEMENU_SHOWBROWSER );
+    
+        /*--------------------------------------*/
+        /* show popup menu */
+    
+        int ret = popupMenu->exec( QCursor::pos() );
+        delete popupMenu;
+        switch ( ret ) {
+    
+        case BEMENU_COPYURL:
+            /* copy */
+            clipboard->setText( strURL, QClipboard::Clipboard );
+            clipboard->setText( strURL, QClipboard::Selection );
+            break;
+    
+        case BEMENU_SHOWBROWSER:
+            emit openURLRequestExt( strURL, KParts::URLArgs(), "text/html" );
+            break;
+    
+        default:
+            break;
+        }
+    } else {
+        emit openURLRequestExt( strURL, KParts::URLArgs(), "text/html" );
+    }
+}
+
+
+
 /*-------------------------------------------------------*/
 /* funtcion when user clicked next 100 ,before 100 ,etc. */
 /* This funtcion is called in only clickAnchor().        */ /* private */
