@@ -57,7 +57,7 @@ KitaThreadTabWidget::~KitaThreadTabWidget() {}
 
 
 /* show "Main thread" view */  /* public slots */
-void KitaThreadTabWidget::slotShowMainThread( const KURL& url, bool withNewTab )
+void KitaThreadTabWidget::slotShowMainThread( const KURL& url, bool withNewTab, bool byBackground )
 {
     QString refstr;
     KURL datURL = Kita::ParseMisc::parseURL( url, refstr );
@@ -88,6 +88,7 @@ void KitaThreadTabWidget::slotShowMainThread( const KURL& url, bool withNewTab )
         else view->slotReloadButton( jumpNum );
 
     } else if ( withNewTab
+                || byBackground
                 || currentView == NULL           /* Current page is not KitaThreadView. */
                 || viewMode != VIEWMODE_MAINVIEW /* Current page is KitaThreadView, but not Main View. */
               ) {
@@ -96,7 +97,9 @@ void KitaThreadTabWidget::slotShowMainThread( const KURL& url, bool withNewTab )
 
         if ( newView ) {
             newView->showThread( datURL, jumpNum );
-            showPage( newView );
+            if ( ! byBackground ) {
+                showPage( newView );
+            }
         }
     } else static_cast<KitaThreadView *>( currentPage() ) ->showThread( datURL, jumpNum );
 
@@ -759,11 +762,11 @@ KitaThreadTabWidget* KitaThreadDock::setupAsMainView()
 }
 
 /* public slot */
-void KitaThreadDock::slotShowThread( const KURL& url, bool withNewTab )
+void KitaThreadDock::slotShowThread( const KURL& url, bool withNewTab, bool byBackground )
 {
     showDock();
 
-    if ( m_threadTab ) m_threadTab->slotShowMainThread( url, withNewTab );
+    if ( m_threadTab ) m_threadTab->slotShowMainThread( url, withNewTab, byBackground );
 }
 
 
