@@ -118,11 +118,11 @@ KitaWriteView::KitaWriteView( QWidget* parent, const char* name, const KURL& url
              SLOT( slotCancel() ) );
 
     connect( this, SIGNAL( openURLRequestExt(
-                               const KURL&, const KParts::URLArgs&, QString, int, int,
-                               const KURL&, const KURL&, const QString&, const QString& ) ),
+                               const KURL&, const KParts::URLArgs&, QString, int,
+                               const KURL& ) ),
              Kita::SignalCollection::getInstance(), SIGNAL( openURLRequestExt(
-                         const KURL& , const KParts::URLArgs&, QString, int, int,
-                         const KURL&, const KURL&, const QString&, const QString& ) ) );
+                         const KURL& , const KParts::URLArgs&, QString, int,
+                         const KURL& ) ) );
 
     connect( faceCombo, SIGNAL( activated( const QString& ) ),
              bodyText, SLOT( insert( const QString& ) ) );
@@ -154,14 +154,34 @@ KitaWriteView::KitaWriteView( QWidget* parent, const char* name, const KURL& url
         threadName->setText( newThreadName );
     }
 
-    nameLine->setText( QString::null );
+    if ( KitaConfig::DefaultNameUseAlways() ) {
+        nameLine->setText( KitaConfig::DefaultName() );
+    } else {
+        QString defaultName = Kita::BoardManager::getBBSDefaultName( m_datURL );
+        if ( defaultName == "fusianasan" || defaultName == "(default name)" ) {
+            nameLine->setText( KitaConfig::DefaultName() );
+        } else {
+            nameLine->setText( defaultName );
+        }
+    }
     KCompletion* comp = KitaConfig::nameCompletion();
     nameLine->setCompletionObject( comp );
 
-    mailLine->setText( "sage" );
-    sageBox->setChecked( true );
+    if ( KitaConfig::DefaultSage() ) {
+        mailLine->setText( "sage" );
+        sageBox->setChecked( true );
+    } else {
+        mailLine->setText( KitaConfig::DefaultMail() );
+    }
     m_mailswap = "";
 
+    QRegExp host_2ch( ".+\\.2ch\\.net" );
+    if ( host_2ch.search( m_bbscgi.host() ) != -1
+        && KitaConfig::BeMailAddress().length() > 0
+        && KitaConfig::BeAuthCode().length() > 0 ) {
+        beBox->setChecked( true );
+    }
+
     /* setup AA */
     faceCombo->clear();
     faceCombo->setFont( KitaConfig::threadFont() );
@@ -273,6 +293,11 @@ void KitaWriteView::slotPostMessage()
     job->addMetaData( "content-type", "Content-type: application/x-www-form-urlencoded" );
     job->addMetaData( "referrer", refStr );
 
+    /* 2ch.net cookie modify */
+    if ( m_bbstype == Kita::Board_2ch ) {
+        set2chCookieStr( job );
+    }
+
     connect( job, SIGNAL( data( KIO::Job*, const QByteArray& ) ),
              this, SLOT( slotRecieveData( KIO::Job*, const QByteArray& ) ) );
 
@@ -654,6 +679,8 @@ int KitaWriteView::resultCode( const QString& response ) const
 /* private */
 QString KitaWriteView::resultMessage( const QString& response ) const
 {
+    QRegExp tags( "(<[^<]+>|</[^<]+>)" );
+    
     if ( m_bbstype == Kita::Board_FlashCGI ) {
 
         QRegExp regexp( "<blockquote>(.*)</blockquote>" );
@@ -665,10 +692,19 @@ QString KitaWriteView::resultMessage( const QString& response ) const
         return QString::null;
     }
 
-    QRegExp regexp( "<b>([^<]*)</b>" );
-    int pos = regexp.search( response );
-    if ( pos != -1 ) {
-        return regexp.cap( 1 );
+    {
+        QRegExp bold_start( "<b>" );
+        QRegExp bold_end( "</b>" );
+        int startPos = bold_start.search( response );
+        if ( startPos != -1 ) {
+            startPos += 3;
+            int endPos = bold_end.search( response );
+            if ( endPos != -1 && startPos < endPos ) {
+                QString message = response.mid( startPos, endPos - startPos );
+                message.remove( tags );
+                return message;
+            }
+        }
     }
 
     QRegExp body_regexp( "<body>([^<]*)</body>" );
@@ -692,3 +728,22 @@ QString KitaWriteView::resultTitle( const QString& response ) const
         return QString::null;
     }
 }
+
+/* create cookie header for 2ch.net */ /* private */
+void KitaWriteView::set2chCookieStr( KIO::TransferJob* job )
+{
+    QString cookie = "Cookie: ";
+
+    /* be */
+    QRegExp host_2ch( ".+\\.2ch\\.net" );
+    if ( host_2ch.search( m_bbscgi.host() ) != -1 && beBox->isChecked() ) {
+        QString BeMailAddress = KitaConfig::BeMailAddress();
+        QString BeAuthCode = KitaConfig::BeAuthCode();
+        if ( BeMailAddress.length() > 0 && BeAuthCode.length() > 0 ) {
+            cookie += "DMDM=" + BeMailAddress + "; ";
+            cookie += "MDMD=" + BeAuthCode + "; ";
+        }
+    }
+
+    job->addMetaData( "customHTTPHeader", cookie );
+}
